/*******************************************************
 Author:					Manfred Langemann
 mailto:					Manfred.Langemann t t-online.de
 Begin of project:			05.06.2021
 Latest version generated:	18.07.2021
 Filename:					StepMotor.h
 Description:				Include File for StepMotor.c
 Microprocessor:			ATmega8
 ********************************************************/
#ifndef _SM_MOTOR
#define _SM_MOTOR
/*
** Define the number of motor steps for one wheel turn.
**	- 200 steps per motor axis turn (1.8 degree per step)
**	- gear ratio is 40 / 12 = 3.33333
*/
#define STEPS_PER_TURN			666		// With gear
#define MAX_SLOW_SPEED_FACTOR	10		// See function Manoeuver_ComputeSlowSpeedLeft/Right()
/*
** Definition of the step motors.
*/
enum SM_DEF
	{
	SM_LEFT_MOTOR,
	SM_RIGHT_MOTOR,
	SM_ONE_MOTOR,
	};
/*
** Definition of input line of L297 step controller: 1=clockwise, 0=counter clockwise
*/
enum SM_DIR
	{
	SM_DIR_CCW,
	SM_DIR_CW,
	};
/*
** Definition for limited or unlimited motor steps to do
*/	
enum SM_STEPS
	{
	SM_STEPS_UNLIMITED,
	SM_STEPS_LIMITED,
	};
/*
** Definition of turn directions of left and right step motor.
*/
#define	SM_LEFT_AHEAD	SM_DIR_CW
#define	SM_LEFT_BACK	SM_DIR_CCW

#define	SM_RIGHT_AHEAD	SM_DIR_CCW
#define	SM_RIGHT_BACK	SM_DIR_CW

/*
** Data structure for communication with TWI master controller.
** This typedef shall be identical with the one in the TWI master controller
*/
typedef struct
	{
	uint8_t iCommand;	// The command byte
	uint8_t iMotor;		// The motor to be addressed {SM_LEFT, SM_RIGHT};
	uint8_t iPara1;		// The 1. parameter of the command
	uint8_t iPara2;		// The 2. parameter of the command
	uint8_t iPara3;		// The 3. parameter of the command
	uint8_t iPara4;		// The 4. parameter of the command
	} TWI_SM_STRUCT;

/*
** Declaration of Public functions.
*/
void SM_Init (void);
/*
** Left Step Motor Functions.
*/
void SM_Left_Start (uint8_t iDirection, uint8_t iSpeed, uint16_t iNumSteps);
void SM_Left_SetSpeed (uint8_t iSpeed);
void SM_Left_Reset (void);
void SM_Left_Stop (void);
uint8_t SM_IsLeftRunning (void);
void SM_Left_Step (void);
void SM_SetLeftSlowSpeedFactor (uint8_t iFactor);
uint8_t SM_GetLeftSlowSpeedFactor (void);
/*
** Right Step Motor Functions.
*/
void SM_Right_Start (uint8_t iDirection, uint8_t iSpeed, uint16_t iNumSteps);
void SM_Right_SetSpeed (uint8_t iSpeed);
void SM_Right_Reset (void);
void SM_Right_Stop (void);
uint8_t SM_IsRightRunning (void);
void SM_SetRightSlowSpeedFactor (uint8_t iFactor);
uint8_t SM_GetRightSlowSpeedFactor (void);

#endif
